==> pw-iso20022-SRU2024-9.5.0-sources.jar: com/prowidesoftware/swift/model/mx/dic/CorporateActionNarrative56.java <==

package com.prowidesoftware.swift.model.mx.dic;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Provides additional information such as the taxation conditions.
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CorporateActionNarrative56", propOrder = {
    "addtlTxt",
    "nrrtvVrsn",
    "infConds",
    "infToCmplyWth",
    "taxtnConds",
    "dsclmr",
    "ptyCtctNrrtv",
    "regnDtls",
    "bsktOrIndxInf",
    "certfctnBrkdwn",
    "prcgTxtForNxtIntrmy"
})
public class CorporateActionNarrative56 {

    @XmlElement(name = "AddtlTxt")
    protected UpdatedAdditionalInformation17 addtlTxt;
    @XmlElement(name = "NrrtvVrsn")
    protected UpdatedAdditionalInformation17 nrrtvVrsn;
    @XmlElement(name = "InfConds")
    protected UpdatedAdditionalInformation17 infConds;
    @XmlElement(name = "InfToCmplyWth")
    protected UpdatedAdditionalInformation17 infToCmplyWth;
    @XmlElement(name = "TaxtnConds")
    protected UpdatedAdditionalInformation17 taxtnConds;
    @XmlElement(name = "Dsclmr")
    protected UpdatedAdditionalInformation17 dsclmr;
    @XmlElement(name = "PtyCtctNrrtv")
    protected UpdatedAdditionalInformation17 ptyCtctNrrtv;
    @XmlElement(name = "RegnDtls")
    protected UpdatedAdditionalInformation17 regnDtls;
    @XmlElement(name = "BsktOrIndxInf")
    protected UpdatedAdditionalInformation17 bsktOrIndxInf;
    @XmlElement(name = "CertfctnBrkdwn")
    protected UpdatedAdditionalInformation17 certfctnBrkdwn;
    @XmlElement(name = "PrcgTxtForNxtIntrmy")
    protected UpdatedAdditionalInformation17 prcgTxtForNxtIntrmy;

    /**
     * Gets the value of the addtlTxt property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public UpdatedAdditionalInformation17 getAddtlTxt() {
        return addtlTxt;
    }

    /**
     * Sets the value of the addtlTxt property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public CorporateActionNarrative56 setAddtlTxt(UpdatedAdditionalInformation17 value) {
        this.addtlTxt = value;
        return this;
    }

    /**
     * Gets the value of the nrrtvVrsn property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public UpdatedAdditionalInformation17 getNrrtvVrsn() {
        return nrrtvVrsn;
    }

    /**
     * Sets the value of the nrrtvVrsn property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public CorporateActionNarrative56 setNrrtvVrsn(UpdatedAdditionalInformation17 value) {
        this.nrrtvVrsn = value;
        return this;
    }

    /**
     * Gets the value of the infConds property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public UpdatedAdditionalInformation17 getInfConds() {
        return infConds;
    }

    /**
     * Sets the value of the infConds property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public CorporateActionNarrative56 setInfConds(UpdatedAdditionalInformation17 value) {
        this.infConds = value;
        return this;
    }

    /**
     * Gets the value of the infToCmplyWth property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public UpdatedAdditionalInformation17 getInfToCmplyWth() {
        return infToCmplyWth;
    }

    /**
     * Sets the value of the infToCmplyWth property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public CorporateActionNarrative56 setInfToCmplyWth(UpdatedAdditionalInformation17 value) {
        this.infToCmplyWth = value;
        return this;
    }

    /**
     * Gets the value of the taxtnConds property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public UpdatedAdditionalInformation17 getTaxtnConds() {
        return taxtnConds;
    }

    /**
     * Sets the value of the taxtnConds property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public CorporateActionNarrative56 setTaxtnConds(UpdatedAdditionalInformation17 value) {
        this.taxtnConds = value;
        return this;
    }

    /**
     * Gets the value of the dsclmr property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public UpdatedAdditionalInformation17 getDsclmr() {
        return dsclmr;
    }

    /**
     * Sets the value of the dsclmr property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public CorporateActionNarrative56 setDsclmr(UpdatedAdditionalInformation17 value) {
        this.dsclmr = value;
        return this;
    }

    /**
     * Gets the value of the ptyCtctNrrtv property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public UpdatedAdditionalInformation17 getPtyCtctNrrtv() {
        return ptyCtctNrrtv;
    }

    /**
     * Sets the value of the ptyCtctNrrtv property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public CorporateActionNarrative56 setPtyCtctNrrtv(UpdatedAdditionalInformation17 value) {
        this.ptyCtctNrrtv = value;
        return this;
    }

    /**
     * Gets the value of the regnDtls property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public UpdatedAdditionalInformation17 getRegnDtls() {
        return regnDtls;
    }

    /**
     * Sets the value of the regnDtls property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public CorporateActionNarrative56 setRegnDtls(UpdatedAdditionalInformation17 value) {
        this.regnDtls = value;
        return this;
    }

    /**
     * Gets the value of the bsktOrIndxInf property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public UpdatedAdditionalInformation17 getBsktOrIndxInf() {
        return bsktOrIndxInf;
    }

    /**
     * Sets the value of the bsktOrIndxInf property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public CorporateActionNarrative56 setBsktOrIndxInf(UpdatedAdditionalInformation17 value) {
        this.bsktOrIndxInf = value;
        return this;
    }

    /**
     * Gets the value of the certfctnBrkdwn property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public UpdatedAdditionalInformation17 getCertfctnBrkdwn() {
        return certfctnBrkdwn;
    }

    /**
     * Sets the value of the certfctnBrkdwn property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public CorporateActionNarrative56 setCertfctnBrkdwn(UpdatedAdditionalInformation17 value) {
        this.certfctnBrkdwn = value;
        return this;
    }

    /**
     * Gets the value of the prcgTxtForNxtIntrmy property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public UpdatedAdditionalInformation17 getPrcgTxtForNxtIntrmy() {
        return prcgTxtForNxtIntrmy;
    }

    /**
     * Sets the value of the prcgTxtForNxtIntrmy property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public CorporateActionNarrative56 setPrcgTxtForNxtIntrmy(UpdatedAdditionalInformation17 value) {
        this.prcgTxtForNxtIntrmy = value;
        return this;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

}

==> pw-iso20022-SRU2024-10.2.9-sources.jar: com/prowidesoftware/swift/model/mx/dic/CorporateActionNarrative56.java <==

package com.prowidesoftware.swift.model.mx.dic;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Provides additional information such as the taxation conditions.
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CorporateActionNarrative56", propOrder = {
    "addtlTxt",
    "nrrtvVrsn",
    "infConds",
    "infToCmplyWth",
    "taxtnConds",
    "dsclmr",
    "ptyCtctNrrtv",
    "regnDtls",
    "bsktOrIndxInf",
    "certfctnBrkdwn",
    "prcgTxtForNxtIntrmy"
})
public class CorporateActionNarrative56 {

    @XmlElement(name = "AddtlTxt")
    protected UpdatedAdditionalInformation17 addtlTxt;
    @XmlElement(name = "NrrtvVrsn")
    protected UpdatedAdditionalInformation17 nrrtvVrsn;
    @XmlElement(name = "InfConds")
    protected UpdatedAdditionalInformation17 infConds;
    @XmlElement(name = "InfToCmplyWth")
    protected UpdatedAdditionalInformation17 infToCmplyWth;
    @XmlElement(name = "TaxtnConds")
    protected UpdatedAdditionalInformation17 taxtnConds;
    @XmlElement(name = "Dsclmr")
    protected UpdatedAdditionalInformation17 dsclmr;
    @XmlElement(name = "PtyCtctNrrtv")
    protected UpdatedAdditionalInformation17 ptyCtctNrrtv;
    @XmlElement(name = "RegnDtls")
    protected UpdatedAdditionalInformation17 regnDtls;
    @XmlElement(name = "BsktOrIndxInf")
    protected UpdatedAdditionalInformation17 bsktOrIndxInf;
    @XmlElement(name = "CertfctnBrkdwn")
    protected UpdatedAdditionalInformation17 certfctnBrkdwn;
    @XmlElement(name = "PrcgTxtForNxtIntrmy")
    protected UpdatedAdditionalInformation17 prcgTxtForNxtIntrmy;

    /**
     * Gets the value of the addtlTxt property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public UpdatedAdditionalInformation17 getAddtlTxt() {
        return addtlTxt;
    }

    /**
     * Sets the value of the addtlTxt property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public CorporateActionNarrative56 setAddtlTxt(UpdatedAdditionalInformation17 value) {
        this.addtlTxt = value;
        return this;
    }

    /**
     * Gets the value of the nrrtvVrsn property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public UpdatedAdditionalInformation17 getNrrtvVrsn() {
        return nrrtvVrsn;
    }

    /**
     * Sets the value of the nrrtvVrsn property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public CorporateActionNarrative56 setNrrtvVrsn(UpdatedAdditionalInformation17 value) {
        this.nrrtvVrsn = value;
        return this;
    }

    /**
     * Gets the value of the infConds property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public UpdatedAdditionalInformation17 getInfConds() {
        return infConds;
    }

    /**
     * Sets the value of the infConds property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public CorporateActionNarrative56 setInfConds(UpdatedAdditionalInformation17 value) {
        this.infConds = value;
        return this;
    }

    /**
     * Gets the value of the infToCmplyWth property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public UpdatedAdditionalInformation17 getInfToCmplyWth() {
        return infToCmplyWth;
    }

    /**
     * Sets the value of the infToCmplyWth property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public CorporateActionNarrative56 setInfToCmplyWth(UpdatedAdditionalInformation17 value) {
        this.infToCmplyWth = value;
        return this;
    }

    /**
     * Gets the value of the taxtnConds property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public UpdatedAdditionalInformation17 getTaxtnConds() {
        return taxtnConds;
    }

    /**
     * Sets the value of the taxtnConds property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public CorporateActionNarrative56 setTaxtnConds(UpdatedAdditionalInformation17 value) {
        this.taxtnConds = value;
        return this;
    }

    /**
     * Gets the value of the dsclmr property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public UpdatedAdditionalInformation17 getDsclmr() {
        return dsclmr;
    }

    /**
     * Sets the value of the dsclmr property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public CorporateActionNarrative56 setDsclmr(UpdatedAdditionalInformation17 value) {
        this.dsclmr = value;
        return this;
    }

    /**
     * Gets the value of the ptyCtctNrrtv property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public UpdatedAdditionalInformation17 getPtyCtctNrrtv() {
        return ptyCtctNrrtv;
    }

    /**
     * Sets the value of the ptyCtctNrrtv property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public CorporateActionNarrative56 setPtyCtctNrrtv(UpdatedAdditionalInformation17 value) {
        this.ptyCtctNrrtv = value;
        return this;
    }

    /**
     * Gets the value of the regnDtls property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public UpdatedAdditionalInformation17 getRegnDtls() {
        return regnDtls;
    }

    /**
     * Sets the value of the regnDtls property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public CorporateActionNarrative56 setRegnDtls(UpdatedAdditionalInformation17 value) {
        this.regnDtls = value;
        return this;
    }

    /**
     * Gets the value of the bsktOrIndxInf property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public UpdatedAdditionalInformation17 getBsktOrIndxInf() {
        return bsktOrIndxInf;
    }

    /**
     * Sets the value of the bsktOrIndxInf property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public CorporateActionNarrative56 setBsktOrIndxInf(UpdatedAdditionalInformation17 value) {
        this.bsktOrIndxInf = value;
        return this;
    }

    /**
     * Gets the value of the certfctnBrkdwn property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public UpdatedAdditionalInformation17 getCertfctnBrkdwn() {
        return certfctnBrkdwn;
    }

    /**
     * Sets the value of the certfctnBrkdwn property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public CorporateActionNarrative56 setCertfctnBrkdwn(UpdatedAdditionalInformation17 value) {
        this.certfctnBrkdwn = value;
        return this;
    }

    /**
     * Gets the value of the prcgTxtForNxtIntrmy property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public UpdatedAdditionalInformation17 getPrcgTxtForNxtIntrmy() {
        return prcgTxtForNxtIntrmy;
    }

    /**
     * Sets the value of the prcgTxtForNxtIntrmy property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation17 }
     *     
     */
    public CorporateActionNarrative56 setPrcgTxtForNxtIntrmy(UpdatedAdditionalInformation17 value) {
        this.prcgTxtForNxtIntrmy = value;
        return this;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

}
